@@ -1,5 +1,6 @@
 //
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1994, 1995, 2015, 2018
+//  by Mike Romberg ( romberg@fsl.noaa.gov )
 //  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
 //
 //  Most of this code was written by Werner Fink <werner@suse.de>
@@ -13,30 +14,20 @@
 //    authors for a copy.
 //
 
-#ifndef _LOADMETER_H_
-#define _LOADMETER_H_
+#ifndef loadmeter_h
+#define loadmeter_h
 
-#include "fieldmetergraph.h"
-#include "xosview.h"
+#include "cloadmeter.h"
 
 
-class LoadMeter : public FieldMeterGraph {
+
+class LoadMeter : public ComLoadMeter {
 public:
-	LoadMeter( XOSView *parent );
-	~LoadMeter( void );
-
-	const char *name( void ) const { return "LoadMeter"; }
-	void checkevent( void );
-	void checkResources( void );
+    LoadMeter(void);
 
 protected:
-	void getloadinfo( void );
-
-private:
-	unsigned long procloadcol_, warnloadcol_, critloadcol_;
-	int warnThreshold_, critThreshold_, alarmstate_, lastalarmstate_;
-	int old_cpu_speed_, cur_cpu_speed_;
-	bool do_cpu_speed_;
+    virtual float getLoad(void) override;
+    virtual uint64_t getCPUSpeed(void) override;
 };
 
 
