@@ -1,5 +1,6 @@
 //
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1994, 1995, 2015, 2016, 2018
+//  by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  NetBSD port:
 //  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
@@ -13,27 +14,28 @@
 //    authors for a copy.
 //
 
-#ifndef _MEMMETER_H_
-#define _MEMMETER_H_
+#ifndef memmeter_h
+#define memmeter_h
 
 #include "fieldmetergraph.h"
-#include "xosview.h"
+
 
 
 class MemMeter : public FieldMeterGraph {
 public:
-	MemMeter( XOSView *parent );
-	~MemMeter( void );
+    MemMeter(void);
 
-	const char *name( void ) const { return "MemMeter"; }
-	void checkevent( void );
-	void checkResources( void );
-
-protected:
-	void getmeminfo( void );
+    virtual std::string resName(void) const override { return "mem"; }
+    virtual void checkevent(void) override;
+    virtual void checkResources(const ResDB &rdb) override;
 
 private:
-	uint64_t meminfo_[5];
+    std::vector<uint64_t> _meminfo;
+
+    void getmeminfo(void);
+
+    // layout: { active, inactive, wired, cached, free }
+    void getMemStats(std::vector<uint64_t> &meminfo) const;
 };
 
 
